==> zio-aws-gamelift_2.12-5.19.7.5-sources.jar: zio/aws/gamelift/model/DescribeGameServerResponse.scala <==
package zio.aws.gamelift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeGameServerResponse(
    gameServer: Optional[zio.aws.gamelift.model.GameServer] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.gamelift.model.DescribeGameServerResponse = {
    import DescribeGameServerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.gamelift.model.DescribeGameServerResponse
      .builder()
      .optionallyWith(gameServer.map(value => value.buildAwsValue()))(
        _.gameServer
      )
      .build()
  }
  def asReadOnly: zio.aws.gamelift.model.DescribeGameServerResponse.ReadOnly =
    zio.aws.gamelift.model.DescribeGameServerResponse.wrap(buildAwsValue())
}
object DescribeGameServerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.gamelift.model.DescribeGameServerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.gamelift.model.DescribeGameServerResponse =
      zio.aws.gamelift.model
        .DescribeGameServerResponse(gameServer.map(value => value.asEditable))
    def gameServer: Optional[zio.aws.gamelift.model.GameServer.ReadOnly]
    def getGameServer
        : ZIO[Any, AwsError, zio.aws.gamelift.model.GameServer.ReadOnly] =
      AwsError.unwrapOptionField("gameServer", gameServer)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.gamelift.model.DescribeGameServerResponse
  ) extends zio.aws.gamelift.model.DescribeGameServerResponse.ReadOnly {
    override val gameServer
        : Optional[zio.aws.gamelift.model.GameServer.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.gameServer())
        .map(value => zio.aws.gamelift.model.GameServer.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.gamelift.model.DescribeGameServerResponse
  ): zio.aws.gamelift.model.DescribeGameServerResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-gamelift_2.13-5.17.116.2-sources.jar: zio/aws/gamelift/model/DescribeGameServerResponse.scala <==
package zio.aws.gamelift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeGameServerResponse(
    gameServer: Option[zio.aws.gamelift.model.GameServer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.gamelift.model.DescribeGameServerResponse = {
    import DescribeGameServerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.gamelift.model.DescribeGameServerResponse
      .builder()
      .optionallyWith(gameServer.map(value => value.buildAwsValue()))(
        _.gameServer
      )
      .build()
  }
  def asReadOnly: zio.aws.gamelift.model.DescribeGameServerResponse.ReadOnly =
    zio.aws.gamelift.model.DescribeGameServerResponse.wrap(buildAwsValue())
}
object DescribeGameServerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.gamelift.model.DescribeGameServerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.gamelift.model.DescribeGameServerResponse =
      zio.aws.gamelift.model
        .DescribeGameServerResponse(gameServer.map(value => value.asEditable))
    def gameServer: Option[zio.aws.gamelift.model.GameServer.ReadOnly]
    def getGameServer
        : ZIO[Any, AwsError, zio.aws.gamelift.model.GameServer.ReadOnly] =
      AwsError.unwrapOptionField("gameServer", gameServer)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.gamelift.model.DescribeGameServerResponse
  ) extends zio.aws.gamelift.model.DescribeGameServerResponse.ReadOnly {
    override val gameServer
        : Option[zio.aws.gamelift.model.GameServer.ReadOnly] = scala
      .Option(impl.gameServer())
      .map(value => zio.aws.gamelift.model.GameServer.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.gamelift.model.DescribeGameServerResponse
  ): zio.aws.gamelift.model.DescribeGameServerResponse.ReadOnly = new Wrapper(
    impl
  )
}
